@@ -12,7 +12,7 @@
 #              together with the source code.
 # ----------------------------------------------------------------------------
 # $Source: src/quantity/money/__init__.py $
-# $Revision: 2021-07-03T18:45:24+02:00 $
+# $Revision: 2021-07-04T17:16:08+02:00 $
 
 """Currency-safe computations with money amounts.
 
@@ -23,7 +23,7 @@ Registering a currency
 ----------------------
 
 A currency must explicitly be registered as a unit for further use. The
-easiest way to do this is to call the function :func:`registerCurrency`:
+easiest way to do this is to call :meth:`Money.register_currency`:
 
     >>> from quantity.money import Money
     >>> EUR = Money.register_currency('EUR')
@@ -33,12 +33,12 @@ easiest way to do this is to call the function :func:`registerCurrency`:
     >>> EUR, HKD, TND, USD
     (Currency('EUR'), Currency('HKD'), Currency('TND'), Currency('USD'))
 
-The function is backed by a database of currencies defined in ISO 4217. It
+The method is backed by a database of currencies defined in ISO 4217. It
 takes the 3-character ISO 4217 code as parameter.
 
 :class:`Currency` derives from :class:`~quantity.Unit`. Each instance has a
-symbol (which is the 3-character ISO 4217 code) and a name. In addition, it
-holds the smallest fraction defined for amounts in this currency:
+symbol (which is usually the 3-character ISO 4217 code) and a name. In
+addition, it holds the smallest fraction defined for amounts in this currency:
 
     >>> TND.symbol
     'TND'
@@ -389,29 +389,6 @@ class Currency(Unit):
 
     """
 
-    # Args:
-    #     iso_code: ISO 4217 3-character code
-    #     name: name of the currency
-    #     minor_unit: amount of minor unit (as exponent to 10), optional,
-    #         defaults to precision of smallest fraction, if that is given,
-    #         otherwise to 2
-    #     smallest_fraction: smallest fraction available for the currency,
-    #         optional, defaults to Decimal(10) ** -minor_unit. Can also be
-    #         given as a string, as long as it is convertable to a Decimal.
-    #
-    # Raises:
-    #     TypeError: given `iso_code` is not a string
-    #     ValueError: no `iso_code` was given
-    #     TypeError: given `minor_unit` is not an Integral number
-    #     ValueError: given `minor_unit` < 0
-    #     ValueError: given `smallest_fraction` can not be converted to a
-    #         Decimal
-    #     ValueError: given `smallest_fraction` not > 0
-    #     ValueError: 1 is not an integer multiple of given
-    #         `smallest_fraction`
-    #     ValueError: given `smallest_fraction` does not fit given
-    #         `minor_unit`
-
     __slots__ = ['_smallest_fraction']
 
     # TODO: remove these class variables after mypy issue #1021 got fixed:
@@ -444,7 +421,32 @@ class MoneyMeta(QuantityMeta):
                  minor_unit: Optional[int] = None,
                  smallest_fraction: Union[Real, str, None] = None) \
             -> Currency:
-        """Create, register and return a new `Currency` instance."""
+        """Create, register and return a new `Currency` instance.
+
+        Args:
+            symbol: symbol of the currency (should be a ISO 4217 3-character
+                code, if possible)
+            name: name of the currency
+            minor_unit: amount of minor unit (as exponent to 10), optional,
+                defaults to precision of smallest fraction, if that is given,
+                otherwise to 2
+            smallest_fraction: smallest fraction available for the currency,
+                optional, defaults to Decimal(10) ** -minor_unit. Can also be
+                given as a string, as long as it is convertable to a Decimal.
+
+        Raises:
+            TypeError: given `symbol` is not a string
+            ValueError: no `symbol` was given
+            TypeError: given `minor_unit` is not an Integral number
+            ValueError: given `minor_unit` < 0
+            ValueError: given `smallest_fraction` can not be converted to a
+                Decimal
+            ValueError: given `smallest_fraction` not > 0
+            ValueError: 1 is not an integer multiple of given
+                `smallest_fraction`
+            ValueError: given `smallest_fraction` does not fit given
+                `minor_unit`
+        """
         if minor_unit is not None:
             if not isinstance(minor_unit, Integral):
                 raise TypeError("'minor_unit' must be an Integral number.")
